@@ -27,11 +27,16 @@
 
 from .logger_main import *
 
-__version__: str = "v0.7.0"
-
+__version__: str = "v0.7.3"
 
 set_version(__version__)
 
+
+def get_version() -> str:
+    """获取版本号"""
+    return __version__
+
+
 __all__ = [
     "logger",
     "osc_",
@@ -44,6 +49,6 @@ __all__ = [
     "ObjectStateConstant",
     "PipManage",
     "py_version",
-    "__version__",
+    "get_version",
     "log__init__",
 ]
