@@ -657,15 +657,21 @@ pip_list: str = ""
 pip_check: str
 
 
-def log__init__(osc_in: ObjectStateConstant, pip_in: PipManage) -> None:
+def log__init__(osc_in: ObjectStateConstant, pip_in: PipManage, is_regenerate: bool = False) -> None:
     """
     to initialize logger.
-    :param osc_in: need a OSC class.
+    :param osc_in: need an OSC class.
     :param pip_in: need a PM class.
+    :param is_regenerate: if regenerate the log class, set True.
     """
     # 直接用本地变量
     global osc_, logger, pip_list, pip_check
 
+    # 判断是否需要重新生成logger
+    if is_regenerate:
+        logger = Logger()
+        logger.register_traceback()
+
     # osc部分
     osc_ = osc_in
     logger.is_logging = osc_.isLoggingUsing  # 设置是否启用logger
@@ -710,7 +716,7 @@ def log__init__(osc_in: ObjectStateConstant, pip_in: PipManage) -> None:
 # version: get from __init__.py
 __version__: str = ""
 
-T: TypeVar = TypeVar("T")
+T = TypeVar("T")
 L = Literal["DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL"]  # 等级选择列表
 
 # instantiation
